@@ -13,15 +13,15 @@ int main(int argc, char** argv)
     limit = std::atol(argv[1]);
 
   primesieve::iterator it;
-  it.skipto(limit);
+  it.jump_to(limit);
   uint64_t prime = it.prev_prime();
   uint64_t sum = 0;
 
-  // iterate over the primes below 10^9
+  // Backwards iterate over the primes <= 10^9
   for (; prime > 0; prime = it.prev_prime())
     sum += prime;
 
-  std::cout << "Sum of primes < " << limit << " = " << sum << std::endl;
+  std::cout << "Sum of primes <= " << limit << ": " << sum << std::endl;
 
   // Note that since sum is a 64-bit variable the result
   // will be incorrect (due to integer overflow) if
