@@ -48,7 +48,7 @@ git pull
 mkdir build-release
 cd build-release
 
-clang++ -static -O3 -flto -DNDEBUG -D_WIN32_WINNT=0x0A00 -Wall -Wextra -pedantic -I ../include ../src/*.cpp ../src/app/*.cpp -o primesieve.exe
+clang++ -static -O3 -flto -DNDEBUG -D_WIN32_WINNT=0x0A00 -Wall -Wextra -pedantic -I../include -I../src ../src/*.cpp ../src/app/*.cpp -o primesieve.exe
 strip primesieve.exe
 
 # Create a release zip archive
